@@ -249,7 +249,7 @@ public:
     \par gradientHeight: the height of the generated gradient.
     for different heights, the gradient is translated so that it is always at the same position from the bottom
     */
-    virtual void renderWindowBackground(QPainter *p, const QRect &clipRect, const QWidget *widget, const QPalette &pal, int y_shift = -23)
+    virtual void renderWindowBackground(QPainter *p, const QRectF &clipRect, const QWidget *widget, const QPalette &pal, int y_shift = -23)
     {
         renderWindowBackground(p, clipRect, widget, pal.color(widget->window()->backgroundRole()), y_shift);
     }
@@ -260,22 +260,22 @@ public:
     for different heights, the gradient is translated so that it is always at the same position from the bottom
     */
     virtual void
-    renderWindowBackground(QPainter *p, const QRect &clipRect, const QWidget *widget, const QWidget *window, const QPalette &pal, int y_shift = -23)
+    renderWindowBackground(QPainter *p, const QRectF &clipRect, const QWidget *widget, const QWidget *window, const QPalette &pal, int y_shift = -23)
     {
         renderWindowBackground(p, clipRect, widget, window, pal.color(window->backgroundRole()), y_shift);
     }
 
     //* render window background using a given color as a reference
-    virtual void renderWindowBackground(QPainter *p, const QRect &clipRect, const QWidget *widget, const QColor &color, int y_shift = -23)
+    virtual void renderWindowBackground(QPainter *p, const QRectF &clipRect, const QWidget *widget, const QColor &color, int y_shift = -23)
     {
         renderWindowBackground(p, clipRect, widget, widget->window(), color, y_shift);
     }
 
     //* render window background using a given color as a reference
     virtual void
-    renderWindowBackground(QPainter *p, const QRect &clipRect, const QWidget *widget, const QWidget *window, const QColor &color, int y_shift = -23);
+    renderWindowBackground(QPainter *p, const QRectF &clipRect, const QWidget *widget, const QWidget *window, const QColor &color, int y_shift = -23);
 
-    virtual void renderWindowBackground(QPainter *p, const QRect &clipRect, const QRect &windowRect, const QColor &color, int y_shift);
+    virtual void renderWindowBackground(QPainter *p, const QRectF &clipRect, const QRectF &windowRect, const QColor &color, int y_shift);
 
     //@}
 
@@ -398,17 +398,6 @@ public:
     */
     const QWidget *checkAutoFillBackground(const QWidget *) const;
 
-    //*@name background gradient XProperty
-    //@{
-
-    //* set background gradient hint to widget
-    virtual void setHasBackgroundGradient(WId, bool) const;
-
-    //* true if background gradient hint is set
-    virtual bool hasBackgroundGradient(WId) const;
-
-    //@}
-
     //@name high dpi utility functions
     //@{
 
@@ -530,9 +519,6 @@ private:
     //* value for given hint
     bool hasHint(xcb_window_t, xcb_atom_t) const;
 
-    //* background gradient hint atom
-    xcb_atom_t _backgroundGradientAtom;
-
 #endif
 
     bool _isX11;
